<?php
/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Dojo
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: FormTest.php 23927 2011-05-02 19:24:53Z matthew $
 */

// Call Zend_Dojo_View_Helper_FormTest::main() if this source file is executed directly.
if (!defined("PHPUnit_MAIN_METHOD")) {
    define("PHPUnit_MAIN_METHOD", "Zend_Dojo_View_Helper_FormTest::main");
}

/** Zend_Dojo_View_Helper_Form */
require_once 'Zend/Dojo/View/Helper/Form.php';

/** Zend_View */
require_once 'Zend/View.php';

/** Zend_Registry */
require_once 'Zend/Registry.php';

/** Zend_Dojo_View_Helper_Dojo */
require_once 'Zend/Dojo/View/Helper/Dojo.php';

/**
 * Test class for Zend_Dojo_View_Helper_Form.
 *
 * @category   Zend
 * @package    Zend_Dojo
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @group      Zend_Dojo
 * @group      Zend_Dojo_View
 */
class Zend_Dojo_View_Helper_FormTest extends PHPUnit_Framework_TestCase
{
    /**
     * Runs the test methods of this class.
     *
     * @return void
     */
    public static function main()
    {
        $suite  = new PHPUnit_Framework_TestSuite("Zend_Dojo_View_Helper_FormTest");
        $result = PHPUnit_TextUI_TestRunner::run($suite);
    }

    /**
     * Sets up the fixture, for example, open a network connection.
     * This method is called before a test is executed.
     *
     * @return void
     */
    public function setUp()
    {
        Zend_Registry::_unsetInstance();
        Zend_Dojo_View_Helper_Dojo::setUseDeclarative();

        $this->view   = $this->getView();
        $this->helper = new Zend_Dojo_View_Helper_Form();
        $this->helper->setView($this->view);
    }

    /**
     * Tears down the fixture, for example, close a network connection.
     * This method is called after a test is executed.
     *
     * @return void
     */
    public function tearDown()
    {
    }

    public function getView()
    {
        require_once 'Zend/View.php';
        $view = new Zend_View();
        $view->addHelperPath('Zend/Dojo/View/Helper/', 'Zend_Dojo_View_Helper');
        return $view;
    }

    public function getForm()
    {
        return $this->helper->form('myForm', array('action' => '/foo'), '');
    }

    public function testShouldAllowDeclarativeDijitCreation()
    {
        $html = $this->getForm();
        $this->assertRegexp('/<form[^>]*(dojoType="dijit.form.Form")/', $html, $html);
    }

    public function testShouldAllowProgrammaticDijitCreation()
    {
        Zend_Dojo_View_Helper_Dojo::setUseProgrammatic();
        $html = $this->getForm();
        $this->assertNotRegexp('/<form[^>]*(dojoType="dijit.form.Form")/', $html);
        $this->assertNotNull($this->view->dojo()->getDijit('myForm'));
    }

    public function testOnlyIdShouldBeNecessary()
    {
        Zend_Dojo_View_Helper_Dojo::setUseDeclarative();
        $html = $this->view->form('foo');
        $this->assertRegexp('/<form[^>]*(dojoType="dijit.form.Form")/', $html, $html);
        $this->assertRegexp('/<form[^>]*(id="foo")/', $html, $html);
    }

    public function testShouldNotRenderIdAsHtmlIdWhenIdPassedAsAttrib()
    {
        $html = $this->helper->form('foo', array('id' => 'bar'));
        $this->assertRegexp('/<form[^>]*(id="bar")/', $html);
    }
    
    public function testShouldNotRenderClosingTagIfContentIsFalse()
    {
        $html = $this->helper->form('foo');
        $this->assertNotRegexp('/<\/form>/', $html);
    }
}

// Call Zend_Dojo_View_Helper_FormTest::main() if this source file is executed directly.
if (PHPUnit_MAIN_METHOD == "Zend_Dojo_View_Helper_FormTest::main") {
    Zend_Dojo_View_Helper_FormTest::main();
}
